---
website: https://www.getmonero.org/
obj: concept
---

# Monero
Monero is a privacy-focused cryptocurrency that prioritizes anonymity and security in transactions. Launched in April 2014, Monero (XMR) has gained popularity for its commitment to providing private and untraceable transactions on a blockchain.

## Features
### 1. **Privacy and Fungibility**
Monero employs advanced cryptographic techniques, including ring signatures and stealth addresses, to ensure that transactions are private and unlinkable. This focus on privacy enhances fungibility, as all units of Monero are considered equal and indistinguishable.
### 2. **Ring Signatures**
Monero uses ring signatures to mix a user's transaction with others, making it difficult to determine the actual sender. This ensures that the true origin of funds remains confidential.
### 3. **Stealth Addresses**
Stealth addresses generate a one-time address for each transaction, making it virtually impossible to trace funds back to the recipient. This feature enhances the privacy of the receiver.
### 4. **Ring Confidential Transactions (RingCT)**
RingCT further improves privacy by concealing transaction amounts. This is achieved by allowing users to prove the validity of their transaction without revealing the exact amount involved.
### 5. **Dynamic Block Size and Fees**
Monero dynamically adjusts block size and fees based on network demand, ensuring scalability and preventing congestion.

## How Monero Works
Monero's privacy features are implemented through a combination of cryptographic techniques. When a user initiates a transaction, the following process occurs:
1. **Ring Signature Generation:**
    - The sender's public key is combined with several other public keys from the blockchain to create a ring signature.
    - This signature authenticates the transaction without revealing the actual sender.
2. **Stealth Address Generation:**
    - The recipient's public address is masked by a one-time stealth address created for the specific transaction.
    - This ensures that the recipient's identity remains private.
3. **RingCT Implementation:**
    - RingCT obscures the transaction amount, providing an additional layer of privacy.
    - It allows for the verification of transaction validity without disclosing specific amounts.
4. **Dynamic Block Size and Fees:**
    - Monero adjusts block size and fees dynamically, allowing for scalability and preventing congestion.

## monero-cli-wallet
`monero-wallet-cli` is the wallet software shipped in the Monero archives. It is a console program, and manages an account.

Generate new wallet:
```shell
monero-wallet-cli --generate-new-wallet <file>
```

Use existing wallet:
```shell
monero-wallet-cli --wallet-file <file> --password-file <passwd>
````

### Commands
| Command                                       | Description                                                  |
| --------------------------------------------- | ------------------------------------------------------------ |
| `wallet_info`                                 | Show wallet main address and other info                      |
| `balance`                                     | Show balance                                                 |
| `address all`                                 | Show all addresses                                           |
| `address new [<label>]`                       | Create new subaddress                                        |
| `transfer <address> <amount>`                 | Send XMR to an address                                       |
| `show_transfers [in/out/pending/failed/pool]` | Show transactions                                            |
| `sweep_all <address>`                         | Send whole balance to another wallet                         |
| `seed`                                        | Show secret 25 words that can be used to recover this wallet |
| `refresh`                                     | Synchronize wallet with the Monero network                   |
| `status`                                      | Check current status of wallet                               |

## Applications
- [Monero GUI](../applications/mobile/Monero%20GUI.md) - Official Monero GUI
- [Feather Wallet](../applications/Feather%20Wallet.md) - Open source wallet

## Sites accepting Monero
[List of supported sites](https://monerica.com/)

| Site                                  | Description |
| ------------------------------------- | ----------- |
| [Mullvad VPN](https://mullvad.net/de) | VPN         | 
